@@ -1,9 +1,11 @@
 """ ioflo package
 
 """
-#print "\nPackage at%s" % __path__[0]
+#print("\nPackage at {0}".format( __path__[0]))
 
-__version__ = "0.9.17"
+from __future__ import division
+
+__version__ = "0.9.18"
 __author__ = "Samuel M. Smith"
 __license__ =  "MIT"
 
@@ -17,4 +19,4 @@ console.profuse("{0} version {1}\n".format(__path__[0], __version__))
 __all__ = ['base', 'trim']
 
 for m in __all__:
-    exec "from . import %s" % m  #relative import
+    exec("from . import {0}".format(m))  #relative import
