@@ -2,17 +2,17 @@
 
 
 """
-#print "\nPackage at %s" % __path__[0]
+#print "Package at {0}".format(__path__[0])
 
 __all__ = ['globaling', 'aiding', 'excepting', 'interfacing',
-           'registering', 'storing', 'skedding', 
+           'registering', 'storing', 'skedding',
            'tasking', 'framing', 'logging', 'serving', 'monitoring',
            'acting', 'poking', 'goaling', 'needing', 'traiting',
            'fiating', 'wanting','completing','deeding', 'arbiting',
-           'housing', 'building',  'testing'] 
+           'housing', 'building',  'testing']
 
 
 for m in __all__:
-    exec "from . import %s" % m  #relative import
-    #print "Imported %s" % globals().get(m,'')
+    exec("from . import {0}".format(m)) #relative import
+    #print "Imported {0}".format(globals().get(m,''))
 
