@@ -1,9 +1,11 @@
 """aiding.py constants and basic functions
 
 """
-#print "module %s" % __name__
+#print("module {0}".format(__name__))
 
-import exceptions
+from __future__ import division
+
+import sys
 import math
 import types
 import socket
@@ -27,6 +29,49 @@ from .odicting import odict
 from .consoling import getConsole
 console = getConsole()
 
+if sys.version < '3':
+    def b(x):
+        return x
+else:
+    def b(x):
+        return x.encode('ISO-8859-1')
+
+def metaclassify(metaclass):
+    """
+    Class decorator for creating a class with a metaclass.
+    This enables the same syntax to work in both python2 and python3
+    python3 does not support
+        class name(object):
+            __metaclass__ mymetaclass
+    python2 does not support
+        class name(metaclass=mymetaclass):
+
+    Borrowed from six.py add_metaclass decorator
+
+    Usage:
+    @metaclassify(Meta)
+    class MyClass(object):
+        pass
+    That code produces a class equivalent to:
+
+    on Python 3
+    class MyClass(object, metaclass=Meta):
+        pass
+
+    on Python 2
+    class MyClass(object):
+        __metaclass__ = MyMeta
+    """
+    def wrapper(cls):
+        originals = cls.__dict__.copy()
+        originals.pop('__dict__', None)
+        originals.pop('__weakref__', None)
+        for slots_var in originals.get('__slots__', ()):
+            originals.pop(slots_var)
+        return metaclass(cls.__name__, cls.__bases__, originals)
+    return wrapper
+
+
 class Fifo(deque):  #new-style class to add put get methods
     """ Extends deque to support more convenient FIFO queue access
 
@@ -320,7 +365,7 @@ class SerialNB(object):
                 settings[lflag] = (settings[lflag] &  ~(termios.ICANON))
 
             if speed: #in linux the speed flag does not equal value
-                speedattr = "B%d" % speed #convert numeric speed to attribute name string
+                speedattr = "B{0}".format(speed) #convert numeric speed to attribute name string
                 speed = getattr(termios, speedattr)
                 settings[ispeed] = speed
                 settings[ospeed] = speed
@@ -345,7 +390,7 @@ class SerialNB(object):
         line = ''
         try:
             line = os.read(self.fd, bs)  #if no chars available generates exception
-        except OSError, ex1:  #ex1 is the target instance of the exception
+        except OSError as ex1:  #ex1 is the target instance of the exception
             if ex1.errno == errno.EAGAIN: #BSD 35, Linux 11
                 pass #No characters available
             else:
@@ -421,14 +466,14 @@ class ConsoleNB(object):
         line = ''
         try:
             line = os.read(self.fd, bs)
-        except OSError, ex1:  #if no chars available generates exception
+        except OSError as ex1:  #if no chars available generates exception
             try: #need to catch correct exception
                 errno = ex1.args[0] #if args not sequence get TypeError
                 if errno == 35:
                     pass #No characters available
                 else:
                     raise #re raise exception ex1
-            except TypeError, ex2:  #catch args[0] mismatch above
+            except TypeError as ex2:  #catch args[0] mismatch above
                 raise ex1 #ignore TypeError, re-raise exception ex1
 
         return line
@@ -899,12 +944,13 @@ def Just(n, seq):
 just = Just #alias
 
 from abc import ABCMeta,  abstractmethod
+@metaclassify(ABCMeta)
 class NonStringIterable:
     """ Check for iterable that is not a string
         Works in python 2.6 to 3.x with isinstance(x, NonStringIterable)
 
     """
-    __metaclass__ = ABCMeta
+    #__metaclass__ = ABCMeta
 
     @abstractmethod
     def __iter__(self):
@@ -1214,22 +1260,13 @@ def CrabSpeed(track = 0.0,  speed = 2.0, north = 0.0, east = 0.0,
         east = mag * math.sin(DEGTORAD * heading)
 
     track = Wrap2(track)
-
     (A,C) = AlongCrossTrack(track = track, north = north, east = east)
-
-    #print A
-    #print C
     #current compensated course crab = track + delta crab angle
     delta = - RADTODEG * math.asin(C / speed)
     crab = track + delta
-
-
     #B = along track component of compensated course
     B = speed * (math.sin(DEGTORAD * crab) * math.sin(DEGTORAD * track) +
                  math.cos(DEGTORAD * crab) * math.cos(DEGTORAD * track)  )
-
-    #print B
-
     return (crab, delta, B + A)
 
 def CrossProduct3D(a,b):
@@ -1512,7 +1549,7 @@ def HumanLatToFracDeg(latDM):
         lat = - (int(degrees) + (float(minutes) / 60.0))
 
     else:
-        raise ValueError, "Bad format for latitude '%s'" % (latDM)
+        raise ValueError("Bad format for latitude '{0}'".format(latDM))
 
     return (lat)
 
@@ -1539,7 +1576,7 @@ def HumanLonToFracDeg(lonDM):
         lon = - (int(degrees) + (float(minutes) / 60.0))
 
     else:
-        raise ValueError, "Bad format for longitude '%s'" % (lonDM)
+        raise ValueError("Bad format for longitude '{0}'".format(lonDM))
 
     return (lon)
 
@@ -1575,7 +1612,7 @@ def HumanLLToFracDeg(hdm):
         min = float(dm[0][1])
         return (-(deg + min/60.0))
 
-    raise ValueError, "Bad format for lat or lon '%s'" % (hdm)
+    raise ValueError("Bad format for lat or lon '{0}'".format(hdm))
 
 def Midpoint(latDM0, lonDM0, latDM1, lonDM1):
     """Computes the midpoint  of a trackline between
@@ -1689,11 +1726,11 @@ def Blend3(d = 0.0, u = 1.0, s = 0.05):
 
     return b
 
-def PackByte(format = '8',fields = [0x0000]):
-    """Packs fields sequence into one byte using format string.
+def PackByte(fmt = b'8',fields = [0x0000]):
+    """Packs fields sequence into one byte using fmt string.
 
        Each fields element is a bit field and each
-       char in format is the corresponding bit field length.
+       char in fmt is the corresponding bit field length.
        Assumes unsigned fields values.
        Assumes network big endian so first fields element is high order bits.
        Format string is number of bits per bit field
@@ -1701,27 +1738,27 @@ def PackByte(format = '8',fields = [0x0000]):
           that is,   nonzero is True and packs as a 1
        for 2-8 length bit fields the field element is truncated
        to the number of low order bits in the bit field
-       if sum of number of bits in format less than 8 last bits are padded
-       if sum of number of bits in format greater than 8 returns exception
+       if sum of number of bits in fmt less than 8 last bits are padded
+       if sum of number of bits in fmt greater than 8 returns exception
        to pad just use 0 value in source.
        example
        PackByte("1322",(True,4,0,3)). returns 0xc3
     """
-
+    fmt = bytes(fmt)
     byte = 0x00
     bfp = 8 #bit field position
     bu = 0 #bits used
 
-    for i in range(len(format)):
+    for i in range(len(fmt)):
         bits = 0x00
-        bfl = int(format[i])
+        bfl = int(fmt[i:i+1])
 
         if not (0 < bfl <= 8):
-            raise ValueError, "Bit field length in format must be > 0 and <= 8"
+            raise ValueError("Bit field length in fmt must be > 0 and <= 8")
 
         bu += bfl
         if bu > 8:
-            raise ValueError, "Sum of bit field lengths in format must be <= 8"
+            raise ValueError("Sum of bit field lengths in fmt must be <= 8")
 
         if bfl == 1:
             if fields[i]:
@@ -1742,41 +1779,41 @@ def PackByte(format = '8',fields = [0x0000]):
 
 packByte = PackByte # alias
 
-def UnpackByte(format = '11111111', byte = 0x00, boolean = True):
-    """unpacks source byte into tuple of bit fields given by format string.
+def UnpackByte(fmt = b'11111111', byte = 0x00, boolean = True):
+    """unpacks source byte into tuple of bit fields given by fmt string.
 
-       Each char of format is a bit field length.
+       Each char of fmt is a bit field length.
        returns unsigned fields values.
-       Assumes network big endian so first format is high order bits.
+       Assumes network big endian so first fmt is high order bits.
        Format string is number of bits per bit field
        If boolean parameter is True then return boolean values for
           bit fields of length 1
 
-       if sum of number of bits in format less than 8 then remaining
+       if sum of number of bits in fmt less than 8 then remaining
        bits returned as additional element in result.
 
-       if sum of number of bits in format greater than 8 returns exception
+       if sum of number of bits in fmt greater than 8 returns exception
        only low order byte of byte is used.
 
        example
        UnpackByte("1322",0xc3, False ) returns (1,4,0,3)
        UnpackByte("1322",0xc3, True ) returns (True,4,0,3)
     """
-
+    fmt = bytes(fmt)
     fields = [] #list of bit fields
     bfp = 8 #bit field position
     bu = 0 #bits used
     byte &= 0xff #get low order byte
 
-    for i in range(len(format)):
-        bfl = int(format[i])
+    for i in range(len(fmt)):
+        bfl = int(fmt[i:i+1])
 
         if not (0 < bfl <= 8):
-            raise ValueError, "Bit field length in format must be > 0 and <= 8"
+            raise ValueError("Bit field length in fmt must be > 0 and <= 8")
 
         bu += bfl
         if bu > 8:
-            raise ValueError, "Sum of bit field lengths in format must be <= 8"
+            raise ValueError("Sum of bit field lengths in fmt must be <= 8")
 
         mask = (2**bfl - 1) << (bfp - bfl) #make mask
         bits = byte & mask #mask off other bits
@@ -1803,7 +1840,7 @@ def Hexize(s = ''):
     """
     h = ''
     for i in range(len(s)):
-        h += ("%02x" % ord(s[i]))
+        h += ("%02x" % ord(s[i:i+1]))
     return h
 
 hexize = Hexize # alias
@@ -1836,7 +1873,7 @@ binize = Binize # alias
 def Denary2BinaryStr(n, l = 8):
     """ Convert denary integer n to binary string bs, left pad to length l"""
     bs = ''
-    if n < 0:  raise ValueError, "must be a positive integer"
+    if n < 0:  raise ValueError("must be a positive integer")
     if n == 0: return '0'
     while n > 0:
         bs = str(n % 2) + bs
@@ -1862,10 +1899,10 @@ def PrintHex(s, chunk = 0, chunks = 0, silent = False, separator = '.'):
        silent = True means return formatted string but do not print
     """
     if (chunk < 0):
-        raise ValueError, "invalid size of chunk"
+        raise ValueError("invalid size of chunk")
 
     if (chunks < 0):
-        raise ValueError, "invalid chunks per line"
+        raise ValueError("invalid chunks per line")
 
     slen = len(s)
 
@@ -1891,7 +1928,7 @@ def PrintHex(s, chunk = 0, chunks = 0, silent = False, separator = '.'):
             ps += '\n' #newline
 
     if not silent:
-        print ps
+        console.terse("{0}\n".format(ps))
 
     return ps
 
@@ -1905,7 +1942,7 @@ def PrintDecimal(s):
     for i in range(len(s)):
         ps = ps + ("%03d." % ord(s[i]))
     ps = ps[0:-1] #strip trailing .
-    print ps
+    print(ps)
 
 printDecimal = PrintDecimal # alias
 
@@ -1984,7 +2021,7 @@ def Ocfn(filename, openMode = 'r+'):
        Returns file object
     """
     try:
-        newfd = os.open(filename, os.O_EXCL | os.O_CREAT | os.O_RDWR, 0664)
+        newfd = os.open(filename, os.O_EXCL | os.O_CREAT | os.O_RDWR, 436) # 436 == octal 0664
         newfile = os.fdopen(newfd,"w+")
     except OSError as ex:
         if ex.errno == errno.EEXIST:
@@ -1999,7 +2036,7 @@ def Load(file = ""):
     """Loads object from pickled file, returns object"""
 
     if not file:
-        raise ParameterError, "No file to Load form: %s" % file
+        raise ParameterError("No file to Load form: {0}".format(file))
 
     f = open(file,"r+")
     p = pickle.Unpickler(f)
@@ -2013,10 +2050,10 @@ def Dump(it = None, file = ""):
     """Pickles  it object to file"""
 
     if not it:
-        raise ParameterError, "No object to Dump: %s" % str(it)
+        raise ParameterError("No object to Dump: {0}".format(str(it)))
 
     if not file:
-        raise ParameterError, "No file to Dump to: %s" % file
+        raise ParameterError("No file to Dump to: {0}".format(file))
 
 
     f = open(file, "w+")
@@ -2029,10 +2066,10 @@ dump = Dump
 def DumpJson(it = None, filename = "", indent=2):
     """Jsonifys it and dumps it to filename"""
     if not it:
-        raise ValueError, "No object to Dump: {0}".format(it)
+        raise ValueError("No object to Dump: {0}".format(it))
 
     if not filename:
-        raise ValueError, "No file to Dump to: {0}".format(filename)
+        raise ValueError("No file to Dump to: {0}".format(filename))
 
     with ocfn(filename, "w+") as f:
         json.dump(it, f, indent=2)
@@ -2044,7 +2081,7 @@ dumpJson = DumpJson
 def LoadJson(filename = ""):
     """ Loads json object from filename, returns unjsoned object"""
     if not filename:
-        raise ParameterError, "Empty filename to load."
+        raise ParameterError("Empty filename to load.")
 
     with ocfn(filename) as f:
         try:
