@@ -2,14 +2,15 @@
 
 
 """
-#print "module %s" % __name__
+#print("module {0}".format(__name__))
 
 import sys
 import os
 import time
 import datetime
 import copy
-import cStringIO
+import io
+
 
 from collections import deque, MutableSequence, MutableMapping
 
@@ -18,7 +19,7 @@ from .odicting import odict
 
 from . import excepting
 from . import registering
-from . import storing 
+from . import storing
 from . import tasking
 
 from .consoling import getConsole
@@ -28,7 +29,7 @@ console = getConsole()
 
 
 class Logger(tasking.Tasker):
-    """Logger Task Patron Registry Class for managing Logs  
+    """Logger Task Patron Registry Class for managing Logs
 
        Usage:   logger.send(START) to prepare log formats also reopens files
                 logger.send(RUN) runs logs
@@ -39,7 +40,7 @@ class Logger(tasking.Tasker):
           .store = data store for house should be same for all frameworks
 
           .period = desired time in seconds between runs must be non negative, zero means asap
-          .stamp = time when tasker last ran sucessfully (not interrupted by exception) 
+          .stamp = time when tasker last ran sucessfully (not interrupted by exception)
           .status = operational status of tasker
           .desire = desired control asked by this or other taskers
           .runner = generator to run tasker
@@ -52,7 +53,7 @@ class Logger(tasking.Tasker):
           .path = full path name of log directory
 
     """
-    #Counter = 0  
+    #Counter = 0
     #Names = {}
 
     def __init__(self, flushPeriod = 30.0, prefix = './', **kw):
@@ -128,29 +129,29 @@ class Logger(tasking.Tasker):
         """creates log directory path
            creates physical directories on disk
         """
-
-
         try:
             #if repened too quickly could be same so we make a do until kludge
-            path = self.path 
+            path = self.path
 
             i = 0
-            while path == self.path: #do until keep trying until different 
+            while path == self.path: #do until keep trying until different
                 dt = datetime.datetime.now()
-                path = "%s_%s_%04d%02d%02d_%02d%02d%02d" % \
-                    (prefix, self.name, 
-                     dt.year, dt.month, dt.day, dt.hour, dt.minute, dt.second + i)
+                path = "{0}_{1}_{2:04d}{3:02d}{4:02d}_{5:02d}{6:02d}{7:02d}".format(
+                        prefix, self.name, dt.year, dt.month, dt.day, dt.hour,
+                        dt.minute, dt.second + i)
                 path = os.path.abspath(path) #convert to proper absolute path
                 i +=1
 
-            os.makedirs(path)
+            if not os.path.exists(path):
+                os.makedirs(path)
 
-        except OSError, ex1:
-            print "Error: creating log directory %s \n" % (ex1)
+        except OSError as ex:
+            console.terse("Error: creating log directory '{0}'\n".format(ex))
             return False
 
         self.path = path
-        print "     Created Logger %s Directory = %s" % (self.name, self.path)
+        console.concise("     Created Logger {0} Directory= '{1}'\n".format(
+                self.name, self.path))
 
         return True
 
@@ -180,7 +181,7 @@ class Logger(tasking.Tasker):
                     console.profuse("     Attempting Ready Logger {0}\n".format(self.name))
                     #doesn't do anything yet
                     console.terse("     Readied Logger {0} ...\n".format(self.name))
-                    self.status = READIED            
+                    self.status = READIED
 
                 elif control == START:
                     console.profuse("     Attempting Start Logger {0}\n".format(self.name))
@@ -209,7 +210,7 @@ class Logger(tasking.Tasker):
                     self.desire = ABORT
                     self.status = ABORTED
 
-                self.stamp = self.store.stamp 
+                self.stamp = self.store.stamp
 
         finally:
             console.terse("     Exception Causing Abort Logger {0}\n".format(self.name))
@@ -224,7 +225,7 @@ class Log(registering.StoriedRegistry):
 
        Iherited instance attributes:
           .name = unique name for log (group)
-          .store = data store 
+          .store = data store
 
        Instance attributes:
           .stamp = time stamp last time logged used by once and update actions
@@ -236,9 +237,9 @@ class Log(registering.StoriedRegistry):
           .action = function to use when logging
           .header = header for log file
           .formats = ordered dictionary of log format strings
-          .loggees = ordered dictionary of shares to be logged 
+          .loggees = ordered dictionary of shares to be logged
     """
-    Counter = 0  
+    Counter = 0
     Names = {}
 
     def __init__(self, kind = 'text', fileName = '', rule = NEVER, loggees = None, **kw):
@@ -259,7 +260,7 @@ class Log(registering.StoriedRegistry):
 
         self.kind = kind
         if fileName:
-            self.fileName = fileName #file name only 
+            self.fileName = fileName #file name only
         else:
             self.fileName = self.name
         self.path = '' #full dir path name of file
@@ -307,12 +308,12 @@ class Log(registering.StoriedRegistry):
         try:
             self.file = open(self.path, 'a+')
 
-        except IOError, ex1:
-            print "Error: creating log file %s \n" % (ex1)
+        except IOError as ex:
+            console.terse("Error: creating log file '{0}'\n".format(ex))
             self.file = None
             return False
 
-        print "     Created Log file %s " % (self.path)
+        console.concise("     Created Log file '{0}'\n".format(self.path))
 
         return True
 
@@ -338,7 +339,7 @@ class Log(registering.StoriedRegistry):
         if rule is not None:
             self.rule = rule
 
-        if self.rule == ONCE: 
+        if self.rule == ONCE:
             self.action = self.once
         elif self.rule == ALWAYS:
             self.action = self.always
@@ -349,7 +350,7 @@ class Log(registering.StoriedRegistry):
         elif self.rule == LIFO:
             self.action = self.lifo
         elif self.rule == FIFO:
-            self.action = self.fifo         
+            self.action = self.fifo
         else:
             self.action = self.never
 
@@ -360,26 +361,26 @@ class Log(registering.StoriedRegistry):
         console.profuse("     Preparing formats for Log {0}\n".format(self.name))
 
         #build header
-        cf = cStringIO.StringIO()
-        cf.write(self.kind)
-        cf.write('\t')
-        cf.write(LogRuleNames[self.rule])
-        cf.write('\t')
-        cf.write(self.fileName)
-        cf.write('\n')
-        cf.write('_time')
+        cf = io.StringIO()
+        cf.write(unicode(self.kind))
+        cf.write(u'\t')
+        cf.write(unicode(LogRuleNames[self.rule]))
+        cf.write(u'\t')
+        cf.write(unicode(self.fileName))
+        cf.write(u'\n')
+        cf.write(u'_time')
         for tag, loggee in self.loggees.items():
             if len(loggee) > 1:
-                for field in loggee: 
-                    cf.write('\t')
-                    cf.write(tag)
-                    cf.write('.')
-                    cf.write(field)
+                for field in loggee:
+                    cf.write(u'\t')
+                    cf.write(unicode(tag))
+                    cf.write(u'.')
+                    cf.write(unicode(field))
             else:
-                cf.write('\t')
-                cf.write(tag)
+                cf.write(u'\t')
+                cf.write(unicode(tag))
 
-        cf.write('\n')
+        cf.write(u'\n')
         self.header = cf.getvalue()
         cf.close()
 
@@ -420,12 +421,12 @@ class Log(registering.StoriedRegistry):
         self.stamp = self.store.stamp
 
         #should be different if binary kind
-        cf = cStringIO.StringIO() #use string io faster than concatenation
+        cf = io.StringIO() #use string io faster than concatenation
         try:
             text = self.formats['_time'] % self.stamp
         except TypeError:
             text = '%s' % self.stamp
-        cf.write(text)
+        cf.write(unicode(text))
 
         for tag, loggee in self.loggees.items():
             if loggee: #len non zero
@@ -434,20 +435,20 @@ class Log(registering.StoriedRegistry):
                         text = self.formats[tag][field] % value
                     except TypeError:
                         text = '%s' % value
-                    cf.write(text)
+                    cf.write(unicode(text))
 
             else: #no items so just write tab
-                cf.write('\t')
+                cf.write(u'\t')
 
-        cf.write('\n')
+        cf.write(u'\n')
 
         try:
             self.file.write(cf.getvalue())
-        except ValueError, ex1: #if self.file already closed then ValueError
-            print ex1
+        except ValueError as ex: #if self.file already closed then ValueError
+            console.terse("{0}\n".format(ex))
 
         cf.close()
-    
+
     def logSequence(self, fifo=False):
         """ called by conditional actions
             Log and remove all elements of sequence
@@ -460,12 +461,12 @@ class Log(registering.StoriedRegistry):
         self.stamp = self.store.stamp
 
         #should be different if binary kind
-        cf = cStringIO.StringIO() #use string io faster than concatenation
+        cf = io.StringIO() #use string io faster than concatenation
         try:
             stamp = self.formats['_time'] % self.stamp
         except TypeError:
             stamp = '%s' % self.stamp
-        
+
         if self.loggees:
             tag, loggee = self.loggees.items()[0] # only works for one loggee
             if loggee: # not empty
@@ -474,30 +475,30 @@ class Log(registering.StoriedRegistry):
                 if isinstance(value, MutableSequence): #has pop method
                     while value: # not empty
                         d.appendleft(value.pop()) #remove and copy in order
-                
+
                 elif isinstance(value, MutableMapping): # has popitem method
                     while value: # not empty
                         d.appendleft(value.popitem()) #remove and copy in order
-                
+
                 else: #not mutable sequence or mapping so log normally
                     d.appendleft(value)
-                        
+
                 while d: # not empty
                     if fifo:
                         element = d.popleft()
                     else: #lifo
                         element = d.pop()
-                        
+
                     try:
                         text = self.formats[tag][field] % (element, )
                     except TypeError:
                         text = '%s' % element
-                    cf.write("%s\t%s\n" % (stamp, text))                          
-                    
+                    cf.write(u"%s\t%s\n" % (stamp, text))
+
         try:
             self.file.write(cf.getvalue())
-        except ValueError, ex1: #if self.file already closed then ValueError
-            print ex1
+        except ValueError as ex: #if self.file already closed then ValueError
+            console.terse("{0}\n".format(ex))
 
         cf.close()
 
@@ -509,7 +510,7 @@ class Log(registering.StoriedRegistry):
         pass
 
     def once(self):
-        """log once 
+        """log once
            Good for logging paramters that don't change but want record
         """
         if self.stamp is None:
@@ -520,21 +521,21 @@ class Log(registering.StoriedRegistry):
 
         """
         self.log()
-    
+
     def lifo(self):
         """log lifo sequence
-            log elements in lifo order from sequence until empty 
+            log elements in lifo order from sequence until empty
         """
-        self.logSequence()       
-    
+        self.logSequence()
+
     def fifo(self):
         """log fifo sequence
-            log elements in fifo order from sequence until empty 
+            log elements in fifo order from sequence until empty
         """
-        self.logSequence(fifo=True)    
+        self.logSequence(fifo=True)
 
     def update(self):
-        """log if updated 
+        """log if updated
            logs once and then only if updated
         """
         if self.stamp is None: #Always log at least once even if not updated
@@ -564,10 +565,10 @@ class Log(registering.StoriedRegistry):
                     if getattr(last, field) != value:
                         change = True
                         setattr(last, field, value)
-                except AttributeError as ex: # 
+                except AttributeError as ex: #
                     console.terse("Warning: Log {0}, new runtime field"
                                   " '{1}' for loggee {2}\n".format(
-                                      self.name, field, loggee.name))                     
+                                      self.name, field, loggee.name))
 
         if change:
             self.log()
@@ -606,14 +607,14 @@ def TestLog(rule = UPDATE):
     heading = store.create('pose.heading').create(value = 0.0)
     position = store.create('pose.position').create(north = 10.0, east = 5.0)
 
-    log = Log(name = 'test', store = store, kind = 'console', 
+    log = Log(name = 'test', store = store, kind = 'console',
               prefix = 'log', path = './logs/', rule = rule)
     log.addLoggee(tag = 'heading', loggee = 'pose.heading')
     log.addLoggee(tag = 'pos', loggee = 'pose.position')
     log.resolve()
     log.prepare()
 
-    print "logging log %s to file %s" % (log.name, log.fileName)
+    print("logging log %s to file %s" % (log.name, log.fileName))
     log() #log
     for i in range(20):
         store.advanceStamp(0.125)
@@ -651,14 +652,14 @@ def Test(rule = UPDATE):
     heading = store.create('pose.heading').create(value = 0.0)
     position = store.create('pose.position').create(north = 10.0, east = 5.0)
 
-    log = Log(name = 'test', store = store, kind = 'text', 
+    log = Log(name = 'test', store = store, kind = 'text',
               prefix = 'log', path = './logs/', rule = rule)
     log.addLoggee(tag = 'heading', loggee = 'pose.heading')
     log.addLoggee(tag = 'pos', loggee = 'pose.position')
     log.resolve()
 
     logger = Logger(name = 'Test', store = store)
-    logger.addLog(log) 
+    logger.addLog(log)
 
     status = logger.runner.send(START) #also prepares logs
     status = logger.runner.send(RUN)
